module Codeclimate
  module Collectors
    module Messages
      # Used to emit the result of processing a +Requests::VerifyConfiguration+
      # request
      class ConfigurationVerification < Message
        STATES = [
          SUCCESS = "success".freeze,
          ERROR = "error".freeze,
        ].freeze

        attribute :state, String
        attribute :error_messages, Array, optional: true

        validates :state, inclusion: { in: STATES }
        validate :validate_error_messages_match_state
        validate :validate_error_messages_are_strings

        private

        def validate_error_messages_are_strings
          all_strs = (error_messages || []).all? { |m| m.is_a?(String) }
          unless all_strs
            errors.add(:error_message, "must be an array of strings")
          end
        end

        def validate_error_messages_match_state
          if state == ERROR && error_messages.blank?
            errors.add(:error_messages, "are required if the state is 'error'")
          elsif state == SUCCESS && error_messages.present?
            errors.add(:error_messages, "should not be provided if config is valid")
          end
        end
      end
    end
  end
end
