module Codeclimate
  module Collectors
    module Messages
      # Represents an incident from an Incident Response Platform, such as
      # PagerDuty.
      class Incident < Message
        STATUSES = [
          TRIGGERED = "triggered".freeze,
          ACKNOWLEDGED = "acknowledged".freeze,
          RESOLVED = "resolved".freeze,
        ].freeze

        # The unique identifier of this incident within the IRP. Often this is
        # an +id+ key in API responses.
        attribute :external_id, String

        # The human-readable title of the incident.
        attribute :title, String

        # The URL a human would visit in a brower to see details of the
        # incident.
        attribute :url, String

        # The incrementing numerical number of the incident.
        attribute :number, Integer

        # The current status of the incident.
        attribute :status, String

        # The time the incident began.
        attribute :created_at, Time

        validates :status, inclusion: { in: STATUSES }

        def self.ordering_keys
          [:external_id]
        end
      end
    end
  end
end
