module Codeclimate
  module Collectors
    class MessagesFacade
      # Wraps functionality for sending messages. Takes care of some basic
      # validation and such so that individual implementations don't need to.
      #
      # +implementation+ should respond to +#send_message+.
      def initialize(implementation:)
        @implementation = implementation
      end

      def send_message(message)
        if !message.valid?
          raise Messages::InvalidMessage, message.errors.full_messages.to_sentence
        end
        implementation.send_message(message)
      end

      def <<(message)
        send_message(message)
      end

      private

      attr_reader :implementation
    end
  end
end
